==> kimageannotator_0.5.2.orig.tar.gz: kImageAnnotator-0.5.2/translations/kImageAnnotator_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id_ID">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Atur</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Bawa ke Depan</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Bawa paling depan</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Kirim paling belakang</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Kirim ke belakang</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Pilih ini</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Tempel</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Sunting</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Pengaturan Umum</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Warna</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Warna Teks</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Lebar</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Nomor Seed</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Faktor Obfuscation</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Bayangan item</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Pengaturan item</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Tutup lainnya</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tutup semua</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Tutup semua ke kiri</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Tutup semua ke kanan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Seleksi Alat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktifkan</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Nonaktifkan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>T:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Terapkan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Batas dan visibilitas isian</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Batas dan Isian</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Batas dan Tanpa Isian</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Tanpa Batas dan Tanpa Isian</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Ukuran font</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tebal</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Miring</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Garis bawah</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efek gambar</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Tanpa Efek</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Bayangan Jatuh</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Skala Abu-abu</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Batas</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Balikkan Warna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Dibatasi</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Saat diaktifkan akan membuat kanvas
menyertakan gambar latar belakang.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>T:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Terapkan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Warna:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Warna Latar Belakang Kanvas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Putar gambar</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Serarah jarum jam</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Sembarang</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Nilai positif berputar searah jarum jam, nilai negatif berlawanan arah jarum jam.
Memutar dengan pengganda non 90° mungkin mengurangi kualitasnya.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Balik</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skala gambar</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Jaga Rasio Aspek</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lebar:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Tinggi:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Persen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Stiker</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pena</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nomor</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marker Persegi Panjang</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Penanda Elips</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Spidol</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Anak panah</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Panah Ganda</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Garis</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Blur</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Persegi</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Penunjuk Angka</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Stiker</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelate</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Penunjuk Teks</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Panah Teks</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Panah Angka</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Perbesar (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Perkecil (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Setel Ulang Zoom (%1)</translation>
    </message>
</context>
</TS>

==> kimageannotator_0.7.2.orig.tar.gz: kImageAnnotator-0.7.2/translations/kImageAnnotator_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id_ID">
<context>
    <name>kImageAnnotator::AnnotationContextMenu</name>
    <message>
        <source>Arrange</source>
        <translation>Atur</translation>
    </message>
    <message>
        <source>Bring to Front</source>
        <translation>Bawa ke Depan</translation>
    </message>
    <message>
        <source>Bring Forward</source>
        <translation>Bawa paling depan</translation>
    </message>
    <message>
        <source>Send Backward</source>
        <translation>Kirim paling belakang</translation>
    </message>
    <message>
        <source>Send to Back</source>
        <translation>Kirim ke belakang</translation>
    </message>
    <message>
        <source>Select This</source>
        <translation>Pilih ini</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Salin</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Tempel</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Sunting</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Hapus</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationControlsWidget</name>
    <message>
        <source>Controls</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationGeneralSettings</name>
    <message>
        <source>General Settings</source>
        <translation>Pengaturan Umum</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationImageSettings</name>
    <message>
        <source>Image Settings</source>
        <translation>Pengaturan Gambar</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationItemSettings</name>
    <message>
        <source>Color</source>
        <translation>Warna</translation>
    </message>
    <message>
        <source>Text Color</source>
        <translation>Warna Teks</translation>
    </message>
    <message>
        <source>Width</source>
        <translation>Lebar</translation>
    </message>
    <message>
        <source>Number Seed</source>
        <translation>Nomor Seed</translation>
    </message>
    <message>
        <source>Obfuscation Factor</source>
        <translation>Faktor Obfuscation</translation>
    </message>
    <message>
        <source>Item Shadow</source>
        <translation>Bayangan item</translation>
    </message>
    <message>
        <source>Item Settings</source>
        <translation>Pengaturan item</translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationTabContextMenu</name>
    <message>
        <source>Close</source>
        <translation>Tutup</translation>
    </message>
    <message>
        <source>Close Other</source>
        <translation>Tutup lainnya</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tutup semua</translation>
    </message>
    <message>
        <source>Close All to the Left</source>
        <translation>Tutup semua ke kiri</translation>
    </message>
    <message>
        <source>Close All to the Right</source>
        <translation>Tutup semua ke kanan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::AnnotationToolSelection</name>
    <message>
        <source>Tool Selection</source>
        <translation>Seleksi Alat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::BoolPicker</name>
    <message>
        <source>Enabled</source>
        <translation>Aktifkan</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Nonaktifkan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::Controls</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation type="unfinished">Putar</translation>
    </message>
    <message>
        <source>Modify canvas</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cut</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CropWidget</name>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>T:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Terapkan</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::CutWidget</name>
    <message>
        <source>Vertical</source>
        <translation type="unfinished">Vertikal</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation type="unfinished">Horisontal</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Terapkan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Batal</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FillModePicker</name>
    <message>
        <source>Border And Fill Visibility</source>
        <translation>Batas dan visibilitas isian</translation>
    </message>
    <message>
        <source>Border and Fill</source>
        <translation>Batas dan Isian</translation>
    </message>
    <message>
        <source>Border and No Fill</source>
        <translation>Batas dan Tanpa Isian</translation>
    </message>
    <message>
        <source>No Border and No Fill</source>
        <translation>Tanpa Batas dan Tanpa Isian</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::FontPicker</name>
    <message>
        <source>Font Size</source>
        <translation>Ukuran font</translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Tebal</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Miring</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Garis bawah</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ImageEffectPicker</name>
    <message>
        <source>Image Effects</source>
        <translation>Efek gambar</translation>
    </message>
    <message>
        <source>No Effect</source>
        <translation>Tanpa Efek</translation>
    </message>
    <message>
        <source>Drop Shadow</source>
        <translation>Bayangan Jatuh</translation>
    </message>
    <message>
        <source>Grayscale</source>
        <translation>Skala Abu-abu</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Batas</translation>
    </message>
    <message>
        <source>Invert Color</source>
        <translation>Balikkan Warna</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ModifyCanvasWidget</name>
    <message>
        <source>Restricted</source>
        <translation>Dibatasi</translation>
    </message>
    <message>
        <source>When enabled enforces the canvas
to include the background image.</source>
        <translation>Saat diaktifkan akan membuat kanvas
menyertakan gambar latar belakang.</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>W:</source>
        <translation>L:</translation>
    </message>
    <message>
        <source>H:</source>
        <translation>T:</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Terapkan</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Warna:</translation>
    </message>
    <message>
        <source>Canvas Background Color</source>
        <translation>Warna Latar Belakang Kanvas</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::RotateDialog</name>
    <message>
        <source>Rotate Image</source>
        <translation>Putar gambar</translation>
    </message>
    <message>
        <source>180°</source>
        <translation>180°</translation>
    </message>
    <message>
        <source>90° Clockwise</source>
        <translation>90° Serarah jarum jam</translation>
    </message>
    <message>
        <source>90° Counter Clockwise</source>
        <translation>90° Berlawanan jarum jam</translation>
    </message>
    <message>
        <source>Arbitrary</source>
        <translation>Sembarang</translation>
    </message>
    <message>
        <source>Positive values rotate clockwise, negative values counter clockwise.
Rotating by non 90° multipliers might introduce loss of quality.</source>
        <translation>Nilai positif berputar searah jarum jam, nilai negatif berlawanan arah jarum jam.
Memutar dengan pengganda non 90° mungkin mengurangi kualitasnya.</translation>
    </message>
    <message>
        <source>Horizontal</source>
        <translation>Horisontal</translation>
    </message>
    <message>
        <source>Vertical</source>
        <translation>Vertikal</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Rotate</source>
        <translation>Putar</translation>
    </message>
    <message>
        <source>Flip</source>
        <translation>Balik</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ScaleDialog</name>
    <message>
        <source>Scale Image</source>
        <translation>Skala gambar</translation>
    </message>
    <message>
        <source>Keep Aspect Ratio</source>
        <translation>Jaga Rasio Aspek</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Lebar:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Tinggi:</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Batal</translation>
    </message>
    <message>
        <source>Pixel</source>
        <translation>Piksel</translation>
    </message>
    <message>
        <source>Percent</source>
        <translation>Persen</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::StickerPicker</name>
    <message>
        <source>Sticker</source>
        <translation>Stiker</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ToolPicker</name>
    <message>
        <source>Select</source>
        <translation>Pilih</translation>
    </message>
    <message>
        <source>Pen</source>
        <translation>Pena</translation>
    </message>
    <message>
        <source>Number</source>
        <translation>Nomor</translation>
    </message>
    <message>
        <source>Marker Rectangle</source>
        <translation>Marker Persegi Panjang</translation>
    </message>
    <message>
        <source>Marker Ellipse</source>
        <translation>Penanda Elips</translation>
    </message>
    <message>
        <source>Marker Pen</source>
        <translation>Spidol</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Teks</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Anak panah</translation>
    </message>
    <message>
        <source>Double Arrow</source>
        <translation>Panah Ganda</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Garis</translation>
    </message>
    <message>
        <source>Blur</source>
        <translation>Blur</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Persegi</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Elips</translation>
    </message>
    <message>
        <source>Number Pointer</source>
        <translation>Penunjuk Angka</translation>
    </message>
    <message>
        <source>Sticker</source>
        <translation>Stiker</translation>
    </message>
    <message>
        <source>Pixelate</source>
        <translation>Pixelate</translation>
    </message>
    <message>
        <source>Text Pointer</source>
        <translation>Penunjuk Teks</translation>
    </message>
    <message>
        <source>Text Arrow</source>
        <translation>Panah Teks</translation>
    </message>
    <message>
        <source>Number Arrow</source>
        <translation>Panah Angka</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplikat</translation>
    </message>
</context>
<context>
    <name>kImageAnnotator::ZoomPicker</name>
    <message>
        <source>Zoom In (%1)</source>
        <translation>Perbesar (%1)</translation>
    </message>
    <message>
        <source>Zoom Out (%1)</source>
        <translation>Perkecil (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom (%1)</source>
        <translation>Setel Ulang Zoom (%1)</translation>
    </message>
    <message>
        <source>Reset Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit image to view (%1)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
